@@ -104,7 +104,7 @@ class ComputeDVARS(BaseInterface):
 
     input_spec = ComputeDVARSInputSpec
     output_spec = ComputeDVARSOutputSpec
-    references_ = [
+    _references = [
         {
             "entry": BibTeX(
                 """\
@@ -311,7 +311,7 @@ class FramewiseDisplacement(BaseInterface):
     input_spec = FramewiseDisplacementInputSpec
     output_spec = FramewiseDisplacementOutputSpec
 
-    references_ = [
+    _references = [
         {
             "entry": BibTeX(
                 """\
@@ -556,7 +556,7 @@ class CompCor(SimpleInterface):
 
     input_spec = CompCorInputSpec
     output_spec = CompCorOutputSpec
-    references_ = [
+    _references = [
         {
             "tags": ["method", "implementation"],
             "entry": BibTeX(
@@ -577,7 +577,7 @@ class CompCor(SimpleInterface):
     ]
 
     def __init__(self, *args, **kwargs):
-        """ exactly the same as compcor except the header """
+        """exactly the same as compcor except the header"""
         super(CompCor, self).__init__(*args, **kwargs)
         self._header = "CompCor"
 
@@ -613,7 +613,7 @@ class CompCor(SimpleInterface):
 
         if len(mask_images) == 0:
             img = nb.Nifti1Image(
-                np.ones(imgseries.shape[:3], dtype=np.bool),
+                np.ones(imgseries.shape[:3], dtype=bool),
                 affine=imgseries.affine,
                 header=imgseries.header,
             )
@@ -774,7 +774,7 @@ class ACompCor(CompCor):
     """
 
     def __init__(self, *args, **kwargs):
-        """ exactly the same as compcor except the header """
+        """exactly the same as compcor except the header"""
         super(ACompCor, self).__init__(*args, **kwargs)
         self._header = "aCompCor"
 
@@ -825,7 +825,7 @@ class TCompCor(CompCor):
     output_spec = TCompCorOutputSpec
 
     def __init__(self, *args, **kwargs):
-        """ exactly the same as compcor except the header """
+        """exactly the same as compcor except the header"""
         super(TCompCor, self).__init__(*args, **kwargs)
         self._header = "tCompCor"
         self._mask_files = []
@@ -835,7 +835,7 @@ class TCompCor(CompCor):
         self._mask_files = []
         timeseries = np.asanyarray(timeseries)
         for i, img in enumerate(mask_images):
-            mask = np.asanyarray(img.dataobj).astype(np.bool)
+            mask = np.asanyarray(img.dataobj).astype(bool)
             imgseries = timeseries[mask, :]
             imgseries = regress_poly(2, imgseries)[0]
             tSTD = _compute_tSTD(imgseries, 0, axis=-1)
@@ -1379,7 +1379,7 @@ def compute_noise_components(
     md_retained = []
 
     for name, img in zip(mask_names, mask_images):
-        mask = np.asanyarray(nb.squeeze_image(img).dataobj).astype(np.bool)
+        mask = np.asanyarray(nb.squeeze_image(img).dataobj).astype(bool)
         if imgseries.shape[:3] != mask.shape:
             raise ValueError(
                 "Inputs for CompCor, timeseries and mask, do not have "
