@@ -17,15 +17,15 @@ from ...interfaces import vtkbase as VTKInfo
 def test_ident_distances(tmpdir):
     tmpdir.chdir()
 
-    in_surf = example_data('surf01.vtk')
+    in_surf = example_data("surf01.vtk")
     dist_ident = m.ComputeMeshWarp()
     dist_ident.inputs.surface1 = in_surf
     dist_ident.inputs.surface2 = in_surf
-    dist_ident.inputs.out_file = tmpdir.join('distance.npy').strpath
+    dist_ident.inputs.out_file = tmpdir.join("distance.npy").strpath
     res = dist_ident.run()
     assert res.outputs.distance == 0.0
 
-    dist_ident.inputs.weighting = 'area'
+    dist_ident.inputs.weighting = "area"
     res = dist_ident.run()
     assert res.outputs.distance == 0.0
 
@@ -34,8 +34,8 @@ def test_ident_distances(tmpdir):
 def test_trans_distances(tmpdir):
     from ...interfaces.vtkbase import tvtk
 
-    in_surf = example_data('surf01.vtk')
-    warped_surf = tmpdir.join('warped.vtk').strpath
+    in_surf = example_data("surf01.vtk")
+    warped_surf = tmpdir.join("warped.vtk").strpath
 
     inc = np.array([0.7, 0.3, -0.2])
 
@@ -51,10 +51,10 @@ def test_trans_distances(tmpdir):
     dist = m.ComputeMeshWarp()
     dist.inputs.surface1 = in_surf
     dist.inputs.surface2 = warped_surf
-    dist.inputs.out_file = tmpdir.join('distance.npy').strpath
+    dist.inputs.out_file = tmpdir.join("distance.npy").strpath
     res = dist.run()
     assert np.allclose(res.outputs.distance, np.linalg.norm(inc), 4)
-    dist.inputs.weighting = 'area'
+    dist.inputs.weighting = "area"
     res = dist.run()
     assert np.allclose(res.outputs.distance, np.linalg.norm(inc), 4)
 
