@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+"""CMP implements a full processing pipeline for creating connectomes with dMRI data."""
 from .cmtk import ROIGen, CreateMatrix, CreateNodes
 from .nx import NetworkXMetrics, AverageNetworks
 from .parcellation import Parcellate
