@@ -20,7 +20,7 @@ __docformat__ = "restructuredtext"
 
 
 class Info(object):
-    """ Handle dtk output type and version information.
+    """Handle dtk output type and version information.
 
     Examples
     --------
@@ -47,7 +47,7 @@ class Info(object):
         """
         clout = CommandLine(command="dti_recon", terminal_output="allatonce").run()
 
-        if clout.runtime.returncode is not 0:
+        if clout.runtime.returncode != 0:
             return None
 
         dtirecon = clout.runtime.stdout
