@@ -8,7 +8,6 @@ import nibabel as nb
 
 import pytest
 
-from nipype.utils import NUMPY_MMAP
 from nipype.interfaces.freesurfer import model, no_freesurfer
 import nipype.pipeline.engine as pe
 
@@ -17,9 +16,9 @@ import nipype.pipeline.engine as pe
 def test_concatenate(tmpdir):
     tmpdir.chdir()
 
-    in1 = tmpdir.join('cont1.nii').strpath
-    in2 = tmpdir.join('cont2.nii').strpath
-    out = 'bar.nii'
+    in1 = tmpdir.join("cont1.nii").strpath
+    in2 = tmpdir.join("cont2.nii").strpath
+    out = "bar.nii"
 
     data1 = np.zeros((3, 3, 3, 1), dtype=np.float32)
     data2 = np.ones((3, 3, 3, 5), dtype=np.float32)
@@ -31,27 +30,28 @@ def test_concatenate(tmpdir):
 
     # Test default behavior
     res = model.Concatenate(in_files=[in1, in2]).run()
-    assert res.outputs.concatenated_file == tmpdir.join('concat_output.nii.gz').strpath
-    assert np.allclose(nb.load('concat_output.nii.gz').get_data(), out_data)
+    assert res.outputs.concatenated_file == tmpdir.join("concat_output.nii.gz").strpath
+    assert np.allclose(nb.load("concat_output.nii.gz").get_fdata(), out_data)
 
     # Test specified concatenated_file
     res = model.Concatenate(in_files=[in1, in2], concatenated_file=out).run()
     assert res.outputs.concatenated_file == tmpdir.join(out).strpath
-    assert np.allclose(nb.load(out, mmap=NUMPY_MMAP).get_data(), out_data)
+    assert np.allclose(nb.load(out).get_fdata(), out_data)
 
     # Test in workflow
-    wf = pe.Workflow('test_concatenate', base_dir=tmpdir.strpath)
-    concat = pe.Node(model.Concatenate(in_files=[in1, in2],
-                                       concatenated_file=out),
-                     name='concat')
+    wf = pe.Workflow("test_concatenate", base_dir=tmpdir.strpath)
+    concat = pe.Node(
+        model.Concatenate(in_files=[in1, in2], concatenated_file=out), name="concat"
+    )
     wf.add_nodes([concat])
     wf.run()
-    assert np.allclose(nb.load(tmpdir.join(
-                                           'test_concatenate',
-                                            'concat', out).strpath).get_data(),
-                       out_data)
+    assert np.allclose(
+        nb.load(tmpdir.join("test_concatenate", "concat", out).strpath).get_fdata(),
+        out_data,
+    )
 
     # Test a simple statistic
-    res = model.Concatenate(in_files=[in1, in2], concatenated_file=out,
-                            stats='mean').run()
-    assert np.allclose(nb.load(out, mmap=NUMPY_MMAP).get_data(), mean_data)
+    res = model.Concatenate(
+        in_files=[in1, in2], concatenated_file=out, stats="mean"
+    ).run()
+    assert np.allclose(nb.load(out).get_fdata(), mean_data)
