@@ -146,14 +146,12 @@ class FSLCommandInputSpec(CommandLineInputSpec):
 
 
 class FSLCommand(CommandLine):
-    """Base support for FSL commands.
-
-    """
+    """Base support for FSL commands."""
 
     input_spec = FSLCommandInputSpec
     _output_type = None
 
-    references_ = [
+    _references = [
         {
             "entry": BibTeX(
                 "@article{JenkinsonBeckmannBehrensWoolrichSmith2012,"
