@@ -165,21 +165,21 @@ class Level1Design(BaseInterface):
     ):
         """Creates EV files from condition and regressor information.
 
-           Parameters:
-           -----------
+        Parameters:
+        -----------
 
-           runinfo : dict
-               Generated by `SpecifyModel` and contains information
-               about events and other regressors.
-           runidx  : int
-               Index to run number
-           ev_parameters : dict
-               A dictionary containing the model parameters for the
-               given design type.
-           orthogonalization : dict
-               A dictionary of dictionaries specifying orthogonal EVs.
-           contrasts : list of lists
-               Information on contrasts to be evaluated
+        runinfo : dict
+            Generated by `SpecifyModel` and contains information
+            about events and other regressors.
+        runidx  : int
+            Index to run number
+        ev_parameters : dict
+            A dictionary containing the model parameters for the
+            given design type.
+        orthogonalization : dict
+            A dictionary of dictionaries specifying orthogonal EVs.
+        contrasts : list of lists
+            Information on contrasts to be evaluated
         """
         conds = {}
         evname = []
@@ -346,8 +346,7 @@ class Level1Design(BaseInterface):
         return session_info
 
     def _get_func_files(self, session_info):
-        """Returns functional files in the order of runs
-        """
+        """Returns functional files in the order of runs"""
         func_files = []
         for i, info in enumerate(session_info):
             func_files.insert(i, info["scans"])
@@ -457,8 +456,7 @@ class FEATOutputSpec(TraitedSpec):
 
 
 class FEAT(FSLCommand):
-    """Uses FSL feat to calculate first level stats
-    """
+    """Uses FSL feat to calculate first level stats"""
 
     _cmd = "feat"
     input_spec = FEATInputSpec
@@ -518,8 +516,7 @@ class FEATModelOutpuSpec(TraitedSpec):
 
 
 class FEATModel(FSLCommand):
-    """Uses FSL feat_model to generate design.mat files
-    """
+    """Uses FSL feat_model to generate design.mat files"""
 
     _cmd = "feat_model"
     input_spec = FEATModelInputSpec
@@ -937,8 +934,7 @@ class FEATRegisterOutputSpec(TraitedSpec):
 
 
 class FEATRegister(BaseInterface):
-    """Register feat directories to a specific standard
-    """
+    """Register feat directories to a specific standard"""
 
     input_spec = FEATRegisterInputSpec
     output_spec = FEATRegisterOutputSpec
@@ -1104,7 +1100,7 @@ class FLAMEO(FSLCommand):
     input_spec = FLAMEOInputSpec
     output_spec = FLAMEOOutputSpec
 
-    references_ = [
+    _references = [
         {
             "entry": BibTeX(
                 "@article{BeckmannJenkinsonSmith2003,"
@@ -1458,7 +1454,7 @@ class MultipleRegressDesignInputSpec(BaseInterfaceInputSpec):
                         traits.Enum("T"),
                         traits.List(traits.Str),
                         traits.List(traits.Float),
-                    ),
+                    )
                 ),
             ),
         ),
@@ -1886,11 +1882,13 @@ class SmoothEstimateInputSpec(FSLCommandInputSpec):
 class SmoothEstimateOutputSpec(TraitedSpec):
     dlh = traits.Float(desc="smoothness estimate sqrt(det(Lambda))")
     volume = traits.Int(desc="number of voxels in mask")
-    resels = traits.Float(desc="number of resels")
+    resels = traits.Float(
+        desc="volume of resel, in voxels, defined as FWHM_x * FWHM_y * FWHM_z"
+    )
 
 
 class SmoothEstimate(FSLCommand):
-    """ Estimates the smoothness of an image
+    """Estimates the smoothness of an image
 
     Examples
     --------
@@ -2044,7 +2042,7 @@ class ClusterOutputSpec(TraitedSpec):
 
 
 class Cluster(FSLCommand):
-    """ Uses FSL cluster to perform clustering on statistical output
+    """Uses FSL cluster to perform clustering on statistical output
 
     Examples
     --------
@@ -2247,7 +2245,7 @@ class RandomiseInputSpec(FSLCommandInputSpec):
         desc=("carry out Threshold-Free Cluster Enhancement with 2D " "optimisation"),
         argstr="--T2",
     )
-    f_only = traits.Bool(desc="calculate f-statistics only", argstr="--f_only")
+    f_only = traits.Bool(desc="calculate f-statistics only", argstr="--fonly")
     raw_stats_imgs = traits.Bool(
         desc="output raw ( unpermuted ) statistic images", argstr="-R"
     )
