@@ -17,32 +17,18 @@ from .base import (
 
 
 def get_matlab_command():
-    if "NIPYPE_NO_MATLAB" in os.environ:
-        return None
+    """Determine whether Matlab is installed and can be executed."""
+    if "NIPYPE_NO_MATLAB" not in os.environ:
+        from nipype.utils.filemanip import which
 
-    try:
-        matlab_cmd = os.environ["MATLABCMD"]
-    except:
-        matlab_cmd = "matlab"
-
-    try:
-        res = CommandLine(
-            command="which",
-            args=matlab_cmd,
-            resource_monitor=False,
-            terminal_output="allatonce",
-        ).run()
-        matlab_path = res.runtime.stdout.strip()
-    except Exception:
-        return None
-    return matlab_cmd
+        return which(os.getenv("MATLABCMD", "matlab"))
 
 
 no_matlab = get_matlab_command() is None
 
 
 class MatlabInputSpec(CommandLineInputSpec):
-    """ Basic expected inputs to Matlab interface """
+    """Basic expected inputs to Matlab interface"""
 
     script = traits.Str(
         argstr='-r "%s;exit"', desc="m-code to run", mandatory=True, position=-1
@@ -187,7 +173,7 @@ class MatlabCommand(CommandLine):
         return super(MatlabCommand, self)._format_arg(name, trait_spec, value)
 
     def _gen_matlab_command(self, argstr, script_lines):
-        """ Generates commands and, if mfile specified, writes it to disk."""
+        """Generates commands and, if mfile specified, writes it to disk."""
         cwd = os.getcwd()
         mfile = self.inputs.mfile or self.inputs.uses_mcr
         paths = []
