@@ -251,7 +251,7 @@ exit;
 
 
 def no_spm():
-    """ Checks if SPM is NOT installed
+    """Checks if SPM is NOT installed
     used with pytest.mark.skipif decorator to skip tests
     that will fail if spm is not installed"""
 
@@ -290,7 +290,7 @@ class SPMCommand(BaseInterface):
     _paths = None
     _use_mcr = None
 
-    references_ = [
+    _references = [
         {
             "entry": BibTeX(
                 "@book{FrackowiakFristonFrithDolanMazziotta1997,"
