@@ -64,7 +64,7 @@ class CalcCoregAffineOutputSpec(TraitedSpec):
 
 
 class CalcCoregAffine(SPMCommand):
-    """ Uses SPM (spm_coreg) to calculate the transform mapping
+    """Uses SPM (spm_coreg) to calculate the transform mapping
     moving to target. Saves Transform in mat (matlab binary file)
     Also saves inverse transform
 
@@ -90,12 +90,12 @@ class CalcCoregAffine(SPMCommand):
     output_spec = CalcCoregAffineOutputSpec
 
     def _make_inv_file(self):
-        """ makes filename to hold inverse transform if not specified"""
+        """makes filename to hold inverse transform if not specified"""
         invmat = fname_presuffix(self.inputs.mat, prefix="inverse_")
         return invmat
 
     def _make_mat_file(self):
-        """ makes name for matfile if doesn exist"""
+        """makes name for matfile if doesn exist"""
         pth, mv, _ = split_filename(self.inputs.moving)
         _, tgt, _ = split_filename(self.inputs.target)
         mat = os.path.join(pth, "%s_to_%s.mat" % (mv, tgt))
@@ -148,7 +148,7 @@ class ApplyTransformOutputSpec(TraitedSpec):
 
 
 class ApplyTransform(SPMCommand):
-    """ Uses SPM to apply transform stored in a .mat file to given file
+    """Uses SPM to apply transform stored in a .mat file to given file
 
     Examples
     --------
@@ -228,13 +228,13 @@ class ResliceOutputSpec(TraitedSpec):
 
 
 class Reslice(SPMCommand):
-    """ uses  spm_reslice to resample in_file into space of space_defining"""
+    """uses  spm_reslice to resample in_file into space of space_defining"""
 
     input_spec = ResliceInputSpec
     output_spec = ResliceOutputSpec
 
     def _make_matlab_command(self, _):
-        """ generates script"""
+        """generates script"""
         if not isdefined(self.inputs.out_file):
             self.inputs.out_file = fname_presuffix(self.inputs.in_file, prefix="r")
         script = """
@@ -305,7 +305,7 @@ class ApplyInverseDeformationOutput(TraitedSpec):
 
 
 class ApplyInverseDeformation(SPMCommand):
-    """ Uses spm to apply inverse deformation stored in a .mat file or a
+    """Uses spm to apply inverse deformation stored in a .mat file or a
     deformation field to a given file
 
     Examples
@@ -326,8 +326,7 @@ class ApplyInverseDeformation(SPMCommand):
     _jobname = "defs"
 
     def _format_arg(self, opt, spec, val):
-        """Convert input to appropriate format for spm
-        """
+        """Convert input to appropriate format for spm"""
         if opt == "in_files":
             return scans_for_fnames(ensure_list(val))
         if opt == "target":
@@ -402,8 +401,7 @@ class ResliceToReference(SPMCommand):
     _jobname = "defs"
 
     def _format_arg(self, opt, spec, val):
-        """Convert input to appropriate format for spm
-        """
+        """Convert input to appropriate format for spm"""
         if opt == "in_files":
             return scans_for_fnames(ensure_list(val))
         if opt == "target":
@@ -466,7 +464,7 @@ class DicomImportOutputSpec(TraitedSpec):
 
 
 class DicomImport(SPMCommand):
-    """ Uses spm to convert DICOM files to nii or img+hdr.
+    """Uses spm to convert DICOM files to nii or img+hdr.
 
     Examples
     --------
@@ -484,8 +482,7 @@ class DicomImport(SPMCommand):
     _jobname = "dicom"
 
     def _format_arg(self, opt, spec, val):
-        """Convert input to appropriate format for spm
-        """
+        """Convert input to appropriate format for spm"""
         if opt == "in_files":
             return np.array(val, dtype=object)
         if opt == "output_dir":
