@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from .vista import (Vnifti2Image, VtoMat)
+"""VistaSoft contains Matlab code to perform a variety of analysis on MRI data."""
+from .vista import Vnifti2Image, VtoMat
