@@ -1,18 +1,18 @@
+# -*- coding: utf-8 -*-
+import configparser
+
 import os
 import sys
 import subprocess
-try:
-    from ConfigParser import ConfigParser
-except ImportError:
-    from configparser import ConfigParser  # python 3
 
-COMMIT_INFO_FNAME = 'COMMIT_INFO.txt'
+COMMIT_INFO_FNAME = "COMMIT_INFO.txt"
+
 
 def pkg_commit_hash(pkg_path):
-    ''' Get short form of commit hash given directory `pkg_path`
+    """Get short form of commit hash given directory `pkg_path`
 
     There should be a file called 'COMMIT_INFO.txt' in `pkg_path`.  This is a
-    file in INI file format, with at least one section: ``commit hash``, and two
+    file in INI file format, with at least one section: ``commit hash`` and two
     variables ``archive_subst_hash`` and ``install_hash``.  The first has a
     substitution pattern in it which may have been filled by the execution of
     ``git archive`` if this is an archive generated that way.  The second is
@@ -37,32 +37,36 @@ def pkg_commit_hash(pkg_path):
        Where we got the hash from - description
     hash_str : str
        short form of hash
-    '''
+    """
     # Try and get commit from written commit text file
     pth = os.path.join(pkg_path, COMMIT_INFO_FNAME)
     if not os.path.isfile(pth):
-        raise IOError('Missing commit info file %s' % pth)
-    cfg_parser = ConfigParser()
-    cfg_parser.read(pth)
-    archive_subst = cfg_parser.get('commit hash', 'archive_subst_hash')
-    if not archive_subst.startswith('$Format'): # it has been substituted
-        return 'archive substitution', archive_subst
-    install_subst = cfg_parser.get('commit hash', 'install_hash')
-    if install_subst != '':
-        return 'installation', install_subst
+        raise IOError("Missing commit info file %s" % pth)
+    cfg_parser = configparser.RawConfigParser()
+    with open(pth, encoding="utf-8") as fp:
+        cfg_parser.read_file(fp)
+    archive_subst = cfg_parser.get("commit hash", "archive_subst_hash")
+    if not archive_subst.startswith("$Format"):  # it has been substituted
+        return "archive substitution", archive_subst
+    install_subst = cfg_parser.get("commit hash", "install_hash")
+    if install_subst != "":
+        return "installation", install_subst
     # maybe we are in a repository
-    proc = subprocess.Popen('git rev-parse --short HEAD',
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.PIPE,
-                            cwd=pkg_path, shell=True)
+    proc = subprocess.Popen(
+        "git rev-parse --short HEAD",
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        cwd=pkg_path,
+        shell=True,
+    )
     repo_commit, _ = proc.communicate()
     if repo_commit:
-        return 'repository', repo_commit.strip()
-    return '(none found)', '<not found>'
+        return "repository", repo_commit.decode().strip()
+    return "(none found)", "<not found>"
 
 
 def get_pkg_info(pkg_path):
-    ''' Return dict describing the context of this package
+    """Return dict describing the context of this package
 
     Parameters
     ----------
@@ -73,17 +77,20 @@ def get_pkg_info(pkg_path):
     -------
     context : dict
        with named parameters of interest
-    '''
+    """
     src, hsh = pkg_commit_hash(pkg_path)
+    from .info import VERSION
     import networkx
     import nibabel
     import numpy
     import scipy
     import traits
+
     return dict(
         pkg_path=pkg_path,
         commit_source=src,
         commit_hash=hsh,
+        nipype_version=VERSION,
         sys_version=sys.version,
         sys_executable=sys.executable,
         sys_platform=sys.platform,
@@ -91,4 +98,5 @@ def get_pkg_info(pkg_path):
         scipy_version=scipy.__version__,
         networkx_version=networkx.__version__,
         nibabel_version=nibabel.__version__,
-        traits_version=traits.__version__)
+        traits_version=traits.__version__,
+    )
