@@ -21,7 +21,7 @@ the directive `workflow`::
       :graph2use: flat
       :simple_form: no
 
-      from nipype.workflows.dmri.camino.connectivity_mapping import create_connectivity_pipeline
+      from niflow.nipype1.workflows.dmri.camino.connectivity_mapping import create_connectivity_pipeline
       wf = create_connectivity_pipeline()
 
 
@@ -32,7 +32,7 @@ code block in this documentation:
   :graph2use: flat
   :simple_form: no
 
-  from nipype.workflows.dmri.camino.connectivity_mapping import create_connectivity_pipeline
+  from niflow.nipype1.workflows.dmri.camino.connectivity_mapping import create_connectivity_pipeline
   wf = create_connectivity_pipeline()
 
 
@@ -106,17 +106,21 @@ The workflow directive has the following configuration options:
         Provide a customized template for preparing restructured text.
 
 """
-from __future__ import print_function, division, absolute_import, unicode_literals
-
-import sys, os, shutil, io, re, textwrap
+import sys
+import os
+import shutil
+import io
+import re
+import textwrap
 from os.path import relpath
 from errno import EEXIST
 import traceback
 
 missing_imports = []
 try:
-    from docutils.parsers.rst import directives
+    from docutils.parsers.rst import directives, Directive
     from docutils.parsers.rst.directives.images import Image
+
     align = Image.align
 except ImportError as e:
     missing_imports = [str(e)]
@@ -124,75 +128,54 @@ except ImportError as e:
 try:
     # Sphinx depends on either Jinja or Jinja2
     import jinja2
+
     def format_template(template, **kw):
         return jinja2.Template(template).render(**kw)
+
+
 except ImportError as e:
     missing_imports.append(str(e))
     try:
         import jinja
+
         def format_template(template, **kw):
             return jinja.from_string(template, **kw)
+
         missing_imports.pop()
     except ImportError as e:
         missing_imports.append(str(e))
 
-from builtins import str, bytes
-
-PY2 = sys.version_info[0] == 2
-PY3 = sys.version_info[0] == 3
-
-def _mkdirp(folder):
-    """
-    Equivalent to bash's mkdir -p
-    """
-    if sys.version_info > (3, 4, 1):
-        os.makedirs(folder, exist_ok=True)
-        return folder
-
-    try:
-        os.makedirs(folder)
-    except OSError as exc:
-        if exc.errno != EEXIST or not os.path.isdir(folder):
-            raise
-
-    return folder
-
-
-def wf_directive(name, arguments, options, content, lineno,
-                   content_offset, block_text, state, state_machine):
-    if len(missing_imports) == 0:
-        return run(arguments, content, options, state_machine, state, lineno)
-    else:
-        raise ImportError('\n'.join(missing_imports))
-wf_directive.__doc__ = __doc__
 
 def _option_boolean(arg):
     if not arg or not arg.strip():
         # no argument given, assume used as a flag
         return True
-    elif arg.strip().lower() in ('no', '0', 'false'):
+    elif arg.strip().lower() in ("no", "0", "false"):
         return False
-    elif arg.strip().lower() in ('yes', '1', 'true'):
+    elif arg.strip().lower() in ("yes", "1", "true"):
         return True
     else:
         raise ValueError('"%s" unknown boolean' % arg)
 
+
 def _option_graph2use(arg):
-    return directives.choice(arg, ('hierarchical', 'colored', 'flat', 'orig', 'exec'))
+    return directives.choice(arg, ("hierarchical", "colored", "flat", "orig", "exec"))
+
 
 def _option_context(arg):
-    if arg in [None, 'reset', 'close-figs']:
+    if arg in [None, "reset", "close-figs"]:
         return arg
     raise ValueError("argument should be None or 'reset' or 'close-figs'")
 
 
 def _option_format(arg):
-    return directives.choice(arg, ('python', 'doctest'))
+    return directives.choice(arg, ("python", "doctest"))
 
 
 def _option_align(arg):
-    return directives.choice(arg, ("top", "middle", "bottom", "left", "center",
-                                   "right"))
+    return directives.choice(
+        arg, ("top", "middle", "bottom", "left", "center", "right")
+    )
 
 
 def mark_wf_labels(app, document):
@@ -208,76 +191,301 @@ def mark_wf_labels(app, document):
         if labelid is None:
             continue
         node = document.ids[labelid]
-        if node.tagname in ('html_only', 'latex_only'):
+        if node.tagname in ("html_only", "latex_only"):
             for n in node:
-                if n.tagname == 'figure':
+                if n.tagname == "figure":
                     sectname = name
                     for c in n:
-                        if c.tagname == 'caption':
+                        if c.tagname == "caption":
                             sectname = c.astext()
                             break
 
-                    node['ids'].remove(labelid)
-                    node['names'].remove(name)
-                    n['ids'].append(labelid)
-                    n['names'].append(name)
-                    document.settings.env.labels[name] = \
-                        document.settings.env.docname, labelid, sectname
+                    node["ids"].remove(labelid)
+                    node["names"].remove(name)
+                    n["ids"].append(labelid)
+                    n["names"].append(name)
+                    document.settings.env.labels[name] = (
+                        document.settings.env.docname,
+                        labelid,
+                        sectname,
+                    )
                     break
 
 
+class WorkflowDirective(Directive):
+    has_content = True
+    required_arguments = 0
+    optional_arguments = 2
+    final_argument_whitespace = False
+    option_spec = {
+        "alt": directives.unchanged,
+        "height": directives.length_or_unitless,
+        "width": directives.length_or_percentage_or_unitless,
+        "scale": directives.nonnegative_int,
+        "align": _option_align,
+        "class": directives.class_option,
+        "include-source": _option_boolean,
+        "format": _option_format,
+        "context": _option_context,
+        "nofigs": directives.flag,
+        "encoding": directives.encoding,
+        "graph2use": _option_graph2use,
+        "simple_form": _option_boolean,
+    }
+
+    def run(self):
+        if missing_imports:
+            raise ImportError("\n".join(missing_imports))
+
+        document = self.state_machine.document
+        config = document.settings.env.config
+        nofigs = "nofigs" in self.options
+
+        formats = get_wf_formats(config)
+        default_fmt = formats[0][0]
+
+        graph2use = self.options.get("graph2use", "hierarchical")
+        simple_form = self.options.get("simple_form", True)
+
+        self.options.setdefault("include-source", config.wf_include_source)
+        keep_context = "context" in self.options
+        context_opt = None if not keep_context else self.options["context"]
+
+        rst_file = document.attributes["source"]
+        rst_dir = os.path.dirname(rst_file)
+
+        if len(self.arguments):
+            if not config.wf_basedir:
+                source_file_name = os.path.join(
+                    setup.app.builder.srcdir, directives.uri(self.arguments[0])
+                )
+            else:
+                source_file_name = os.path.join(
+                    setup.confdir, config.wf_basedir, directives.uri(self.arguments[0])
+                )
+
+            # If there is content, it will be passed as a caption.
+            caption = "\n".join(self.content)
+
+            # If the optional function name is provided, use it
+            if len(self.arguments) == 2:
+                function_name = self.arguments[1]
+            else:
+                function_name = None
+
+            with io.open(source_file_name, "r", encoding="utf-8") as fd:
+                code = fd.read()
+            output_base = os.path.basename(source_file_name)
+        else:
+            source_file_name = rst_file
+            code = textwrap.dedent("\n".join([str(c) for c in self.content]))
+            counter = document.attributes.get("_wf_counter", 0) + 1
+            document.attributes["_wf_counter"] = counter
+            base, _ = os.path.splitext(os.path.basename(source_file_name))
+            output_base = "%s-%d.py" % (base, counter)
+            function_name = None
+            caption = ""
+
+        base, source_ext = os.path.splitext(output_base)
+        if source_ext in (".py", ".rst", ".txt"):
+            output_base = base
+        else:
+            source_ext = ""
+
+        # ensure that LaTeX includegraphics doesn't choke in foo.bar.pdf filenames
+        output_base = output_base.replace(".", "-")
+
+        # is it in doctest format?
+        is_doctest = contains_doctest(code)
+        if "format" in self.options:
+            if self.options["format"] == "python":
+                is_doctest = False
+            else:
+                is_doctest = True
+
+        # determine output directory name fragment
+        source_rel_name = relpath(source_file_name, setup.confdir)
+        source_rel_dir = os.path.dirname(source_rel_name)
+        while source_rel_dir.startswith(os.path.sep):
+            source_rel_dir = source_rel_dir[1:]
+
+        # build_dir: where to place output files (temporarily)
+        build_dir = os.path.join(
+            os.path.dirname(setup.app.doctreedir), "wf_directive", source_rel_dir
+        )
+        # get rid of .. in paths, also changes pathsep
+        # see note in Python docs for warning about symbolic links on Windows.
+        # need to compare source and dest paths at end
+        build_dir = os.path.normpath(build_dir)
+
+        if not os.path.exists(build_dir):
+            os.makedirs(build_dir)
+
+        # output_dir: final location in the builder's directory
+        dest_dir = os.path.abspath(
+            os.path.join(setup.app.builder.outdir, source_rel_dir)
+        )
+        if not os.path.exists(dest_dir):
+            os.makedirs(dest_dir)  # no problem here for me, but just use built-ins
+
+        # how to link to files from the RST file
+        dest_dir_link = os.path.join(
+            relpath(setup.confdir, rst_dir), source_rel_dir
+        ).replace(os.path.sep, "/")
+        try:
+            build_dir_link = relpath(build_dir, rst_dir).replace(os.path.sep, "/")
+        except ValueError:
+            # on Windows, relpath raises ValueError when path and start are on
+            # different mounts/drives
+            build_dir_link = build_dir
+        source_link = dest_dir_link + "/" + output_base + source_ext
+
+        # make figures
+        try:
+            results = render_figures(
+                code,
+                source_file_name,
+                build_dir,
+                output_base,
+                keep_context,
+                function_name,
+                config,
+                graph2use,
+                simple_form,
+                context_reset=context_opt == "reset",
+                close_figs=context_opt == "close-figs",
+            )
+            errors = []
+        except GraphError as err:
+            reporter = self.state.memo.reporter
+            sm = reporter.system_message(
+                2,
+                "Exception occurred in plotting %s\n from %s:\n%s"
+                % (output_base, source_file_name, err),
+                line=self.lineno,
+            )
+            results = [(code, [])]
+            errors = [sm]
+
+        # Properly indent the caption
+        caption = "\n".join("      " + line.strip() for line in caption.split("\n"))
+
+        # generate output restructuredtext
+        total_lines = []
+        for j, (code_piece, images) in enumerate(results):
+            if self.options["include-source"]:
+                if is_doctest:
+                    lines = [""]
+                    lines += [row.rstrip() for row in code_piece.split("\n")]
+                else:
+                    lines = [".. code-block:: python", ""]
+                    lines += ["    %s" % row.rstrip() for row in code_piece.split("\n")]
+                source_code = "\n".join(lines)
+            else:
+                source_code = ""
+
+            if nofigs:
+                images = []
+
+            opts = [
+                ":%s: %s" % (key, val)
+                for key, val in list(self.options.items())
+                if key in ("alt", "height", "width", "scale", "align", "class")
+            ]
+
+            only_html = ".. only:: html"
+            only_latex = ".. only:: latex"
+            only_texinfo = ".. only:: texinfo"
+
+            # Not-None src_link signals the need for a source link in the generated
+            # html
+            if j == 0 and config.wf_html_show_source_link:
+                src_link = source_link
+            else:
+                src_link = None
+
+            result = format_template(
+                config.wf_template or TEMPLATE,
+                default_fmt=default_fmt,
+                dest_dir=dest_dir_link,
+                build_dir=build_dir_link,
+                source_link=src_link,
+                multi_image=len(images) > 1,
+                only_html=only_html,
+                only_latex=only_latex,
+                only_texinfo=only_texinfo,
+                options=opts,
+                images=images,
+                source_code=source_code,
+                html_show_formats=config.wf_html_show_formats and len(images),
+                caption=caption,
+            )
+
+            total_lines.extend(result.split("\n"))
+            total_lines.extend("\n")
+
+        if total_lines:
+            self.state_machine.insert_input(total_lines, source=source_file_name)
+
+        # copy image files to builder's output directory, if necessary
+        os.makedirs(dest_dir, exist_ok=True)
+        for code_piece, images in results:
+            for img in images:
+                for fn in img.filenames():
+                    destimg = os.path.join(dest_dir, os.path.basename(fn))
+                    if fn != destimg:
+                        shutil.copyfile(fn, destimg)
+
+        # copy script (if necessary)
+        target_name = os.path.join(dest_dir, output_base + source_ext)
+        with io.open(target_name, "w", encoding="utf-8") as f:
+            if source_file_name == rst_file:
+                code_escaped = unescape_doctest(code)
+            else:
+                code_escaped = code
+            f.write(code_escaped)
+
+        return errors
+
+
 def setup(app):
     setup.app = app
     setup.config = app.config
     setup.confdir = app.confdir
 
-    options = {'alt': directives.unchanged,
-               'height': directives.length_or_unitless,
-               'width': directives.length_or_percentage_or_unitless,
-               'scale': directives.nonnegative_int,
-               'align': _option_align,
-               'class': directives.class_option,
-               'include-source': _option_boolean,
-               'format': _option_format,
-               'context': _option_context,
-               'nofigs': directives.flag,
-               'encoding': directives.encoding,
-               'graph2use': _option_graph2use,
-               'simple_form': _option_boolean
-               }
+    app.add_directive("workflow", WorkflowDirective)
+    app.add_config_value("graph2use", "hierarchical", "html")
+    app.add_config_value("simple_form", True, "html")
+    app.add_config_value("wf_pre_code", None, True)
+    app.add_config_value("wf_include_source", False, True)
+    app.add_config_value("wf_html_show_source_link", True, True)
+    app.add_config_value("wf_formats", ["png", "svg", "pdf"], True)
+    app.add_config_value("wf_basedir", None, True)
+    app.add_config_value("wf_html_show_formats", True, True)
+    app.add_config_value("wf_rcparams", {}, True)
+    app.add_config_value("wf_apply_rcparams", False, True)
+    app.add_config_value("wf_working_directory", None, True)
+    app.add_config_value("wf_template", None, True)
 
-    app.add_directive('workflow', wf_directive, True, (0, 2, False), **options)
-    app.add_config_value('graph2use', 'hierarchical', 'html')
-    app.add_config_value('simple_form', True, 'html')
-    app.add_config_value('wf_pre_code', None, True)
-    app.add_config_value('wf_include_source', False, True)
-    app.add_config_value('wf_html_show_source_link', True, True)
-    app.add_config_value('wf_formats', ['png', 'svg', 'pdf'], True)
-    app.add_config_value('wf_basedir', None, True)
-    app.add_config_value('wf_html_show_formats', True, True)
-    app.add_config_value('wf_rcparams', {}, True)
-    app.add_config_value('wf_apply_rcparams', False, True)
-    app.add_config_value('wf_working_directory', None, True)
-    app.add_config_value('wf_template', None, True)
+    app.connect("doctree-read", mark_wf_labels)
 
-    app.connect('doctree-read'.encode() if PY2 else 'doctree-read', mark_wf_labels)
-
-    metadata = {'parallel_read_safe': True, 'parallel_write_safe': True}
+    metadata = {"parallel_read_safe": True, "parallel_write_safe": True}
     return metadata
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Doctest handling
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 def contains_doctest(text):
     try:
         # check if it's valid Python as-is
-        compile(text, '<string>', 'exec')
+        compile(text, "<string>", "exec")
         return False
     except SyntaxError:
         pass
-    r = re.compile(r'^\s*>>>', re.M)
+    r = re.compile(r"^\s*>>>", re.M)
     m = r.search(text)
     return bool(m)
 
@@ -292,7 +500,7 @@ def unescape_doctest(text):
 
     code = ""
     for line in text.split("\n"):
-        m = re.match(r'^\s*(>>>|\.\.\.) (.*)$', line)
+        m = re.match(r"^\s*(>>>|\.\.\.) (.*)$", line)
         if m:
             code += m.group(2) + "\n"
         elif line.strip():
@@ -306,13 +514,13 @@ def remove_coding(text):
     """
     Remove the coding comment, which exec doesn't like.
     """
-    sub_re = re.compile("^#\s*-\*-\s*coding:\s*.*-\*-$", flags=re.MULTILINE)
+    sub_re = re.compile(r"^#\s*-\*-\s*coding:\s*.*-\*-$", flags=re.MULTILINE)
     return sub_re.sub("", text)
 
-#------------------------------------------------------------------------------
-# Template
-#------------------------------------------------------------------------------
 
+# ------------------------------------------------------------------------------
+# Template
+# ------------------------------------------------------------------------------
 
 TEMPLATE = """
 {{ source_code }}
@@ -376,6 +584,7 @@ Exception occurred rendering plot.
 # :context: option
 wf_context = dict()
 
+
 class ImageFile(object):
     def __init__(self, basename, dirname):
         self.basename = basename
@@ -394,9 +603,10 @@ def out_of_date(original, derived):
     Returns True if derivative is out-of-date wrt original,
     both of which are full file paths.
     """
-    return (not os.path.exists(derived) or
-            (os.path.exists(original) and
-             os.stat(derived).st_mtime < os.stat(original).st_mtime))
+    return not os.path.exists(derived) or (
+        os.path.exists(original)
+        and os.stat(derived).st_mtime < os.stat(original).st_mtime
+    )
 
 
 class GraphError(RuntimeError):
@@ -418,13 +628,17 @@ def run_code(code, code_path, ns=None, function_name=None):
         try:
             os.chdir(setup.config.wf_working_directory)
         except OSError as err:
-            raise OSError(str(err) + '\n`wf_working_directory` option in'
-                          'Sphinx configuration file must be a valid '
-                          'directory path')
+            raise OSError(
+                str(err) + "\n`wf_working_directory` option in"
+                "Sphinx configuration file must be a valid "
+                "directory path"
+            )
         except TypeError as err:
-            raise TypeError(str(err) + '\n`wf_working_directory` option in '
-                            'Sphinx configuration file must be a string or '
-                            'None')
+            raise TypeError(
+                str(err) + "\n`wf_working_directory` option in "
+                "Sphinx configuration file must be a string or "
+                "None"
+            )
         sys.path.insert(0, setup.config.wf_working_directory)
     elif code_path is not None:
         dirname = os.path.abspath(os.path.dirname(code_path))
@@ -437,11 +651,7 @@ def run_code(code, code_path, ns=None, function_name=None):
 
     # Redirect stdout
     stdout = sys.stdout
-    if PY3:
-        sys.stdout = io.StringIO()
-    else:
-        from cStringIO import StringIO
-        sys.stdout = StringIO()
+    sys.stdout = io.StringIO()
 
     # Assign a do-nothing print function to the namespace.  There
     # doesn't seem to be any other way to provide a way to (not) print
@@ -457,7 +667,7 @@ def run_code(code, code_path, ns=None, function_name=None):
             if not ns:
                 if setup.config.wf_pre_code is not None:
                     exec(str(setup.config.wf_pre_code), ns)
-            ns['print'] = _dummy_print
+            ns["print"] = _dummy_print
             if "__main__" in code:
                 exec("__name__ = '__main__'", ns)
             code = remove_coding(code)
@@ -473,19 +683,20 @@ def run_code(code, code_path, ns=None, function_name=None):
         sys.stdout = stdout
     return ns
 
+
 def get_wf_formats(config):
-    default_dpi = {'png': 80, 'hires.png': 200, 'pdf': 200}
+    default_dpi = {"png": 80, "hires.png": 200, "pdf": 200}
     formats = []
     wf_formats = config.wf_formats
     if isinstance(wf_formats, (str, bytes)):
         # String Sphinx < 1.3, Split on , to mimic
         # Sphinx 1.3 and later. Sphinx 1.3 always
         # returns a list.
-        wf_formats = wf_formats.split(',')
+        wf_formats = wf_formats.split(",")
     for fmt in wf_formats:
         if isinstance(fmt, (str, bytes)):
-            if ':' in fmt:
-                suffix, dpi = fmt.split(':')
+            if ":" in fmt:
+                suffix, dpi = fmt.split(":")
                 formats.append((str(suffix), int(dpi)))
             else:
                 formats.append((fmt, default_dpi.get(fmt, 80)))
@@ -496,9 +707,19 @@ def get_wf_formats(config):
     return formats
 
 
-def render_figures(code, code_path, output_dir, output_base, context,
-                   function_name, config, graph2use, simple_form,
-                   context_reset=False, close_figs=False):
+def render_figures(
+    code,
+    code_path,
+    output_dir,
+    output_base,
+    context,
+    function_name,
+    config,
+    graph2use,
+    simple_form,
+    context_reset=False,
+    close_figs=False,
+):
     """
     Run a nipype workflow creation script and save the graph in *output_dir*.
     Save the images under *output_dir* with file names derived from
@@ -516,216 +737,14 @@ def render_figures(code, code_path, output_dir, output_base, context,
         try:
             img_path = img.filename(fmt)
             imgname, ext = os.path.splitext(os.path.basename(img_path))
-            ns['wf'].base_dir = output_dir
-            src = ns['wf'].write_graph(imgname, format=ext[1:],
-                                       graph2use=graph2use,
-                                       simple_form=simple_form)
+            ns["wf"].base_dir = output_dir
+            src = ns["wf"].write_graph(
+                imgname, format=ext[1:], graph2use=graph2use, simple_form=simple_form
+            )
             shutil.move(src, img_path)
-        except Exception as err:
+        except Exception:
             raise GraphError(traceback.format_exc())
 
         img.formats.append(fmt)
 
     return [(code, [img])]
-
-
-def run(arguments, content, options, state_machine, state, lineno):
-    document = state_machine.document
-    config = document.settings.env.config
-    nofigs = 'nofigs' in options
-
-    formats = get_wf_formats(config)
-    default_fmt = formats[0][0]
-
-    graph2use = options.get('graph2use', 'hierarchical')
-    simple_form = options.get('simple_form', True)
-
-    options.setdefault('include-source', config.wf_include_source)
-    keep_context = 'context' in options
-    context_opt = None if not keep_context else options['context']
-
-    rst_file = document.attributes['source']
-    rst_dir = os.path.dirname(rst_file)
-
-    if len(arguments):
-        if not config.wf_basedir:
-            source_file_name = os.path.join(setup.app.builder.srcdir,
-                                            directives.uri(arguments[0]))
-        else:
-            source_file_name = os.path.join(setup.confdir, config.wf_basedir,
-                                            directives.uri(arguments[0]))
-
-        # If there is content, it will be passed as a caption.
-        caption = '\n'.join(content)
-
-        # If the optional function name is provided, use it
-        if len(arguments) == 2:
-            function_name = arguments[1]
-        else:
-            function_name = None
-
-        with io.open(source_file_name, 'r', encoding='utf-8') as fd:
-            code = fd.read()
-        output_base = os.path.basename(source_file_name)
-    else:
-        source_file_name = rst_file
-        code = textwrap.dedent("\n".join([str(c) for c in content]))
-        counter = document.attributes.get('_wf_counter', 0) + 1
-        document.attributes['_wf_counter'] = counter
-        base, _ = os.path.splitext(os.path.basename(source_file_name))
-        output_base = '%s-%d.py' % (base, counter)
-        function_name = None
-        caption = ''
-
-    base, source_ext = os.path.splitext(output_base)
-    if source_ext in ('.py', '.rst', '.txt'):
-        output_base = base
-    else:
-        source_ext = ''
-
-    # ensure that LaTeX includegraphics doesn't choke in foo.bar.pdf filenames
-    output_base = output_base.replace('.', '-')
-
-    # is it in doctest format?
-    is_doctest = contains_doctest(code)
-    if 'format' in options:
-        if options['format'] == 'python':
-            is_doctest = False
-        else:
-            is_doctest = True
-
-    # determine output directory name fragment
-    source_rel_name = relpath(source_file_name, setup.confdir)
-    source_rel_dir = os.path.dirname(source_rel_name)
-    while source_rel_dir.startswith(os.path.sep):
-        source_rel_dir = source_rel_dir[1:]
-
-    # build_dir: where to place output files (temporarily)
-    build_dir = os.path.join(os.path.dirname(setup.app.doctreedir),
-                             'wf_directive',
-                             source_rel_dir)
-    # get rid of .. in paths, also changes pathsep
-    # see note in Python docs for warning about symbolic links on Windows.
-    # need to compare source and dest paths at end
-    build_dir = os.path.normpath(build_dir)
-
-    if not os.path.exists(build_dir):
-        os.makedirs(build_dir)
-
-    # output_dir: final location in the builder's directory
-    dest_dir = os.path.abspath(os.path.join(setup.app.builder.outdir,
-                                            source_rel_dir))
-    if not os.path.exists(dest_dir):
-        os.makedirs(dest_dir) # no problem here for me, but just use built-ins
-
-    # how to link to files from the RST file
-    dest_dir_link = os.path.join(relpath(setup.confdir, rst_dir),
-                                 source_rel_dir).replace(os.path.sep, '/')
-    try:
-        build_dir_link = relpath(build_dir, rst_dir).replace(os.path.sep, '/')
-    except ValueError:
-        # on Windows, relpath raises ValueError when path and start are on
-        # different mounts/drives
-        build_dir_link = build_dir
-    source_link = dest_dir_link + '/' + output_base + source_ext
-
-    # make figures
-    try:
-        results = render_figures(code,
-                                 source_file_name,
-                                 build_dir,
-                                 output_base,
-                                 keep_context,
-                                 function_name,
-                                 config,
-                                 graph2use,
-                                 simple_form,
-                                 context_reset=context_opt == 'reset',
-                                 close_figs=context_opt == 'close-figs')
-        errors = []
-    except GraphError as err:
-        reporter = state.memo.reporter
-        sm = reporter.system_message(
-            2, "Exception occurred in plotting %s\n from %s:\n%s" % (output_base,
-                                                source_file_name, err),
-            line=lineno)
-        results = [(code, [])]
-        errors = [sm]
-
-    # Properly indent the caption
-    caption = '\n'.join('      ' + line.strip()
-                        for line in caption.split('\n'))
-
-    # generate output restructuredtext
-    total_lines = []
-    for j, (code_piece, images) in enumerate(results):
-        if options['include-source']:
-            if is_doctest:
-                lines = ['']
-                lines += [row.rstrip() for row in code_piece.split('\n')]
-            else:
-                lines = ['.. code-block:: python', '']
-                lines += ['    %s' % row.rstrip()
-                          for row in code_piece.split('\n')]
-            source_code = "\n".join(lines)
-        else:
-            source_code = ""
-
-        if nofigs:
-            images = []
-
-        opts = [':%s: %s' % (key, val) for key, val in list(options.items())
-                if key in ('alt', 'height', 'width', 'scale', 'align', 'class')]
-
-        only_html = ".. only:: html"
-        only_latex = ".. only:: latex"
-        only_texinfo = ".. only:: texinfo"
-
-        # Not-None src_link signals the need for a source link in the generated
-        # html
-        if j == 0 and config.wf_html_show_source_link:
-            src_link = source_link
-        else:
-            src_link = None
-
-        result = format_template(
-            config.wf_template or TEMPLATE,
-            default_fmt=default_fmt,
-            dest_dir=dest_dir_link,
-            build_dir=build_dir_link,
-            source_link=src_link,
-            multi_image=len(images) > 1,
-            only_html=only_html,
-            only_latex=only_latex,
-            only_texinfo=only_texinfo,
-            options=opts,
-            images=images,
-            source_code=source_code,
-            html_show_formats=config.wf_html_show_formats and len(images),
-            caption=caption)
-
-        total_lines.extend(result.split("\n"))
-        total_lines.extend("\n")
-
-    if total_lines:
-        state_machine.insert_input(total_lines, source=source_file_name)
-
-    # copy image files to builder's output directory, if necessary
-    _mkdirp(dest_dir)
-    for code_piece, images in results:
-        for img in images:
-            for fn in img.filenames():
-                destimg = os.path.join(dest_dir, os.path.basename(fn))
-                if fn != destimg:
-                    shutil.copyfile(fn, destimg)
-
-    # copy script (if necessary)
-    target_name = os.path.join(dest_dir, output_base + source_ext)
-    with io.open(target_name, 'w', encoding="utf-8") as f:
-        if source_file_name == rst_file:
-            code_escaped = unescape_doctest(code)
-        else:
-            code_escaped = code
-        f.write(code_escaped)
-
-    return errors
