@@ -3,34 +3,17 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Miscellaneous utility functions
 """
-from __future__ import (print_function, unicode_literals, division,
-                        absolute_import)
-from builtins import next, bytes, str
-
 import os
 import sys
 import re
-from collections import Iterator
+from collections.abc import Iterator
 from warnings import warn
 
 from distutils.version import LooseVersion
 
 import numpy as np
-from future.utils import raise_from
-from future import standard_library
-try:
-    from textwrap import indent as textwrap_indent
-except ImportError:
 
-    def textwrap_indent(text, prefix):
-        """ A textwrap.indent replacement for Python < 3.3 """
-        if not prefix:
-            return text
-        splittext = text.splitlines(True)
-        return prefix + prefix.join(splittext)
-
-
-standard_library.install_aliases()
+import textwrap
 
 
 def human_order_sorted(l):
@@ -42,17 +25,17 @@ def human_order_sorted(l):
     def natural_keys(text):
         if isinstance(text, tuple):
             text = text[0]
-        return [atoi(c) for c in re.split('(\d+)', text)]
+        return [atoi(c) for c in re.split(r"(\d+)", text)]
 
     return sorted(l, key=natural_keys)
 
 
 def trim(docstring, marker=None):
     if isinstance(docstring, bytes):
-        docstring = str(docstring, 'utf-8')
+        docstring = str(docstring, "utf-8")
 
     if not docstring:
-        return ''
+        return ""
     # Convert tabs to spaces (following the normal Python rules)
     # and split into a list of lines:
     lines = docstring.expandtabs().splitlines()
@@ -68,9 +51,12 @@ def trim(docstring, marker=None):
         for line in lines[1:]:
             # replace existing REST marker with doc level marker
             stripped = line.lstrip().strip().rstrip()
-            if marker is not None and stripped and \
-               all([s == stripped[0] for s in stripped]) and \
-               stripped[0] not in [':']:
+            if (
+                marker is not None
+                and stripped
+                and all([s == stripped[0] for s in stripped])
+                and stripped[0] not in [":"]
+            ):
                 line = line.replace(stripped[0], marker)
             trimmed.append(line[indent:].rstrip())
     # Strip off trailing and leading blank lines:
@@ -79,12 +65,12 @@ def trim(docstring, marker=None):
     while trimmed and not trimmed[0]:
         trimmed.pop(0)
     # Return a single string:
-    return '\n'.join(trimmed)
+    return "\n".join(trimmed)
 
 
 def find_indices(condition):
     "Return the indices where ravel(condition) is true"
-    res, = np.nonzero(np.ravel(condition))
+    (res,) = np.nonzero(np.ravel(condition))
     return res
 
 
@@ -104,7 +90,7 @@ def is_container(item):
     """
     if isinstance(item, str):
         return False
-    elif hasattr(item, '__iter__'):
+    elif hasattr(item, "__iter__"):
         return True
     else:
         return False
@@ -130,19 +116,21 @@ def container_to_string(cont):
         Container elements joined into a string.
 
     """
-    if hasattr(cont, '__iter__') and not isinstance(cont, str):
-        cont = ' '.join(cont)
+    if hasattr(cont, "__iter__") and not isinstance(cont, str):
+        cont = " ".join(cont)
     return str(cont)
 
 
 # Dependency checks.  Copied this from Nipy, with some modificiations
 # (added app as a parameter).
-def package_check(pkg_name,
-                  version=None,
-                  app=None,
-                  checker=LooseVersion,
-                  exc_failed_import=ImportError,
-                  exc_failed_check=RuntimeError):
+def package_check(
+    pkg_name,
+    version=None,
+    app=None,
+    checker=LooseVersion,
+    exc_failed_import=ImportError,
+    exc_failed_check=RuntimeError,
+):
     """Check that the minimal version of the required package is installed.
 
     Parameters
@@ -171,22 +159,21 @@ def package_check(pkg_name,
     """
 
     if app:
-        msg = '%s requires %s' % (app, pkg_name)
+        msg = "%s requires %s" % (app, pkg_name)
     else:
-        msg = 'Nipype requires %s' % pkg_name
+        msg = "Nipype requires %s" % pkg_name
     if version:
-        msg += ' with version >= %s' % (version, )
+        msg += " with version >= %s" % (version,)
     try:
         mod = __import__(pkg_name)
     except ImportError as e:
-        raise_from(exc_failed_import(msg), e)
+        raise exc_failed_import(msg) from e
     if not version:
         return
     try:
         have_version = mod.__version__
     except AttributeError as e:
-        raise_from(
-            exc_failed_check('Cannot find version for %s' % pkg_name), e)
+        raise exc_failed_check("Cannot find version for %s" % pkg_name) from e
     if checker(have_version) < checker(version):
         raise exc_failed_check(msg)
 
@@ -233,7 +220,7 @@ def str2bool(v):
         return v
 
     if isinstance(v, bytes):
-        v = v.decode('utf-8')
+        v = v.decode("utf-8")
 
     if isinstance(v, str):
         lower = v.lower()
@@ -278,13 +265,14 @@ def normalize_mc_params(params, source):
         ry  Roll                (rad)
         rz  Yaw                 (rad)
     """
-    if source.upper() == 'FSL':
+    if source.upper() == "FSL":
         params = params[[3, 4, 5, 0, 1, 2]]
-    elif source.upper() in ('AFNI', 'FSFAST'):
+    elif source.upper() in ("AFNI", "FSFAST"):
         params = params[np.asarray([4, 5, 3, 1, 2, 0]) + (len(params) > 6)]
-        params[3:] = params[3:] * np.pi / 180.
-    elif source.upper() == 'NIPY':
+        params[3:] = params[3:] * np.pi / 180.0
+    elif source.upper() == "NIPY":
         from nipy.algorithms.registration import to_matrix44, aff2euler
+
         matrix = to_matrix44(params)
         params = np.zeros(6)
         params[:3] = matrix[:3, 3]
@@ -299,12 +287,16 @@ def dict_diff(dold, dnew, indent=0):
 
     typical use -- log difference for hashed_inputs
     """
-    # First check inputs, since they usually are lists of tuples
-    # and dicts are required.
-    if isinstance(dnew, list):
-        dnew = dict(dnew)
-    if isinstance(dold, list):
-        dold = dict(dold)
+    try:
+        dnew, dold = dict(dnew), dict(dold)
+    except Exception:
+        return textwrap.indent(
+            f"""\
+Diff between nipype inputs failed:
+* Cached inputs: {dold}
+* New inputs: {dnew}""",
+            " " * indent,
+        )
 
     # Compare against hashed_inputs
     # Keys: should rarely differ
@@ -324,26 +316,36 @@ def dict_diff(dold, dnew, indent=0):
 
     diffkeys = len(diff)
 
+    def _shorten(value):
+        if isinstance(value, str) and len(value) > 50:
+            return f"{value[:10]}...{value[-10:]}"
+        if isinstance(value, (tuple, list)) and len(value) > 10:
+            return tuple(list(value[:2]) + ["..."] + list(value[-2:]))
+        return value
+
+    def _uniformize(val):
+        if isinstance(val, dict):
+            return {k: _uniformize(v) for k, v in val.items()}
+        if isinstance(val, (list, tuple)):
+            return tuple(_uniformize(el) for el in val)
+        return val
+
     # Values in common keys would differ quite often,
     # so we need to join the messages together
     for k in new_keys.intersection(old_keys):
-        try:
-            new, old = dnew[k], dold[k]
-            same = new == old
-            if not same:
-                # Since JSON does not discriminate between lists and
-                # tuples, we might need to cast them into the same type
-                # as the last resort.  And lets try to be more generic
-                same = old.__class__(new) == old
-        except Exception:
-            same = False
-        if not same:
-            diff += ["  * %s: %r != %r" % (k, dnew[k], dold[k])]
+        # Reading from JSON produces lists, but internally we typically
+        # use tuples. At this point these dictionary values can be
+        # immutable (and therefore the preference for tuple).
+        new = _uniformize(dnew[k])
+        old = _uniformize(dold[k])
+
+        if new != old:
+            diff += ["  * %s: %r != %r" % (k, _shorten(new), _shorten(old))]
 
     if len(diff) > diffkeys:
         diff.insert(diffkeys, "Some dictionary entries had differing values:")
 
-    return textwrap_indent('\n'.join(diff), ' ' * indent)
+    return textwrap.indent("\n".join(diff), " " * indent)
 
 
 def rgetcwd(error=True):
@@ -359,10 +361,14 @@ def rgetcwd(error=True):
     except OSError as exc:
         # Changing back to cwd is probably not necessary
         # but this makes sure there's somewhere to change to.
-        cwd = os.getenv('PWD')
+        cwd = os.getenv("PWD")
         if cwd is None:
-            raise OSError((
-                exc.errno, 'Current directory does not exist anymore, '
-                'and nipype was not able to guess it from the environment'))
+            raise OSError(
+                (
+                    exc.errno,
+                    "Current directory does not exist anymore, "
+                    "and nipype was not able to guess it from the environment",
+                )
+            )
         warn('Current folder does not exist, replacing with "%s" instead.' % cwd)
     return cwd
