@@ -1,7 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import str
 import os
 import argparse
 import inspect
@@ -29,13 +26,12 @@ def add_options(parser=None, module=None, function=None):
         interface = getattr(sys.modules[module], function)()
 
         inputs = interface.input_spec()
-        for name, spec in sorted(
-                interface.inputs.traits(transient=None).items()):
-            desc = "\n".join(get_trait_desc(inputs, name, spec))[len(name) + 2:]
+        for name, spec in sorted(interface.inputs.traits(transient=None).items()):
+            desc = "\n".join(get_trait_desc(inputs, name, spec))[len(name) + 2 :]
             args = {}
 
             if spec.is_trait_type(traits.Bool):
-                args["action"] = 'store_true'
+                args["action"] = "store_true"
 
             if hasattr(spec, "mandatory") and spec.mandatory:
                 if spec.is_trait_type(InputMultiPath):
@@ -44,8 +40,7 @@ def add_options(parser=None, module=None, function=None):
             else:
                 if spec.is_trait_type(InputMultiPath):
                     args["nargs"] = "*"
-                parser.add_argument(
-                    "--%s" % name, dest=name, help=desc, **args)
+                parser.add_argument("--%s" % name, dest=name, help=desc, **args)
     return parser, interface
 
 
@@ -58,8 +53,7 @@ def run_instance(interface, options):
             try:
                 setattr(interface.inputs, input_name, value)
             except ValueError as e:
-                print("Error when setting the value of %s: '%s'" % (input_name,
-                                                                    str(e)))
+                print("Error when setting the value of %s: '%s'" % (input_name, str(e)))
 
     print(interface.inputs)
     res = interface.run()
@@ -73,16 +67,18 @@ def main(argv):
         sys.exit(0)
 
     parser = argparse.ArgumentParser(
-        description='Nipype interface runner', prog=argv[0])
+        description="Nipype interface runner", prog=argv[0]
+    )
     parser.add_argument("module", type=str, help="Module name")
     parser.add_argument("interface", type=str, help="Interface name")
     parsed = parser.parse_args(args=argv[1:3])
 
     _, prog = os.path.split(argv[0])
     interface_parser = argparse.ArgumentParser(
-        description="Run %s" % parsed.interface,
-        prog=" ".join([prog] + argv[1:3]))
-    interface_parser, interface = add_options(interface_parser, parsed.module,
-                                              parsed.interface)
+        description="Run %s" % parsed.interface, prog=" ".join([prog] + argv[1:3])
+    )
+    interface_parser, interface = add_options(
+        interface_parser, parsed.module, parsed.interface
+    )
     args = interface_parser.parse_args(args=argv[3:])
     run_instance(interface, args)
