@@ -5,6 +5,7 @@
 Utilities to keep track of performance
 """
 import os
+import numpy as np
 import threading
 from time import time
 
@@ -23,6 +24,24 @@ resource_monitor = config.resource_monitor
 _MB = 1024.0 ** 2
 
 
+class ResourceMonitorMock:
+    """A mock class to use when the monitor is disabled."""
+
+    @property
+    def fname(self):
+        """Get/set the internal filename"""
+        return None
+
+    def __init__(self, pid, freq=5, fname=None, python=True):
+        pass
+
+    def start(self):
+        pass
+
+    def stop(self):
+        return {}
+
+
 class ResourceMonitor(threading.Thread):
     """
     A ``Thread`` to monitor a specific PID with a certain frequence
@@ -57,7 +76,7 @@ class ResourceMonitor(threading.Thread):
         return self._fname
 
     def stop(self):
-        """Stop monitoring"""
+        """Stop monitoring."""
         if not self._event.is_set():
             self._event.set()
             self.join()
@@ -65,6 +84,25 @@ class ResourceMonitor(threading.Thread):
             self._logfile.flush()
             self._logfile.close()
 
+        retval = {
+            "mem_peak_gb": None,
+            "cpu_percent": None,
+        }
+
+        # Read .prof file in and set runtime values
+        vals = np.loadtxt(self._fname, delimiter=",")
+        if vals.size:
+            vals = np.atleast_2d(vals)
+            retval["mem_peak_gb"] = vals[:, 2].max() / 1024
+            retval["cpu_percent"] = vals[:, 1].max()
+            retval["prof_dict"] = {
+                "time": vals[:, 0].tolist(),
+                "cpus": vals[:, 1].tolist(),
+                "rss_GiB": (vals[:, 2] / 1024).tolist(),
+                "vms_GiB": (vals[:, 3] / 1024).tolist(),
+            }
+        return retval
+
     def _sample(self, cpu_interval=None):
         cpu = 0.0
         rss = 0.0
