@@ -23,15 +23,30 @@ UPCOMING=$?
 HEADER="$1 ($(date '+%B %d, %Y'))"
 echo $HEADER >> newchanges
 echo $( printf "%${#HEADER}s" | tr " " "=" ) >> newchanges
+echo >> newchanges
 
 if [[ "x$2" != "x" ]]; then
-	echo "(\`Full changelog <https://github.com/nipy/nipype/milestone/$2?closed=1>\`__)" >> newchanges
+    echo "(\`Full changelog <https://github.com/nipy/nipype/milestone/$2?closed=1>\`__)" >> newchanges
+    echo >> newchanges
 fi
 
 # Search for PRs since previous release
-git log --grep="Merge pull request" `git describe --tags --abbrev=0`..HEAD --pretty='format:  * %b %s' | sed  's+Merge pull request \#\([^\d]*\)\ from\ .*+(https://github.com/nipy/nipype/pull/\1)+' >> newchanges
-echo "" >> newchanges
-echo "" >> newchanges
+MERGE_COMMITS=$( git log --grep="Merge pull request\|(#.*)$" `git describe --tags --abbrev=0`..HEAD --pretty='format:%h' )
+for COMMIT in ${MERGE_COMMITS//\n}; do
+    SUB=$( git log -n 1 --pretty="format:%s" $COMMIT )
+    if ( echo $SUB | grep "^Merge pull request" ); then
+        # Merge commit
+        PR=$( echo $SUB | sed -e "s/Merge pull request \#\([0-9]*\).*/\1/" )
+        TITLE=$( git log -n 1 --pretty="format:%b" $COMMIT )
+    else
+        # Squashed merge
+        PR=$( echo $SUB | sed -e "s/.*(\#\([0-9]*\))$/\1/" )
+        TITLE=$( echo $SUB | sed -e "s/\(.*\)(\#[0-9]*)$/\1/" )
+    fi
+    echo "  * $TITLE (https://github.com/nipy/nipype/pull/$PR)" >> newchanges
+done
+echo >> newchanges
+echo >> newchanges
 
 # Append old CHANGES
 if [[ "$UPCOMING" == "0" ]]; then
@@ -43,4 +58,3 @@ fi
 
 # Replace old CHANGES with new file
 mv newchanges $CHANGES
-
